@@ -43,7 +43,7 @@ WATCHDOG_TIMEOUT = 3
 MAX_BRINGING_TO_PAUSED_DURATION = 5
 MAX_SET_STATE_DURATION = 1
 
-DEFAULT_POSITION_LISTENNING_INTERVAL = 500
+DEFAULT_POSITION_LISTENING_INTERVAL = 10
 
 
 class PipelineError(Exception):
@@ -57,7 +57,7 @@ class SimplePipeline(GObject.Object, Loggable):
      - State changes
      - Position seeking
      - Position querying
-     - Along with an periodic callback (optional)
+     - Along with a periodic callback (optional)
 
     Signals:
         state-change: The state of the pipeline changed.
@@ -85,7 +85,7 @@ class SimplePipeline(GObject.Object, Loggable):
         self._bus.add_signal_watch()
         self._bus.connect("message", self._bus_message_cb)
         self._listening = False  # for the position handler
-        self._listening_interval = DEFAULT_POSITION_LISTENNING_INTERVAL
+        self._listening_interval = DEFAULT_POSITION_LISTENING_INTERVAL
         self._listening_sig_id = 0
         self._duration = Gst.CLOCK_TIME_NONE
         # The last known position.
@@ -247,7 +247,7 @@ class SimplePipeline(GObject.Object, Loggable):
         self._duration = dur
         return dur
 
-    def activate_position_listener(self, interval=DEFAULT_POSITION_LISTENNING_INTERVAL):
+    def activate_position_listener(self, interval=DEFAULT_POSITION_LISTENING_INTERVAL):
         """Activates the position listener.
 
         When activated, the instance will emit the `position` signal at the
@@ -550,6 +550,8 @@ class Pipeline(GES.Pipeline, SimplePipeline):
         self._commit_wanted = False
         self._prevent_commits = 0
 
+        self.props.audio_sink = Gst.parse_bin_from_description("level ! audioconvert ! audioresample ! autoaudiosink", True)
+
         if "watchdog" in os.environ.get("PITIVI_UNSTABLE_FEATURES", ''):
             watchdog = Gst.ElementFactory.make("watchdog", None)
             if watchdog:
